@@ -1,4 +1,5 @@
 from datetime import datetime
+
 from provider_switch.exceptions import ResponseNotFoundException, ValidationResponseException
 from provider_switch.helpers.common_helper import CommonHelper
 from provider_switch.helpers.dotdictify import dotdictify
@@ -6,7 +7,8 @@ from provider_switch.ssm.ssm_client import SSMClient
 
 
 class ProviderModel(object):
-    _excludes = ['_format_values', 'ssm_client', 'status', 'url', 'headers', 'request', 'response']
+    _excludes = ['_format_values', 'ssm_client', 'status', 'url', 'headers', 'request', 'response',
+        'retry_when_not_found']
 
     def __init__(self, **kwargs):
         self.id = kwargs.get('id', None)
@@ -27,6 +29,7 @@ class ProviderModel(object):
         self.session_fail = 0
         self.session_success = 0
         self.retry_delay = kwargs.get('retry_delay', 2)
+        self.retry_when_not_found = kwargs.get('retry_when_not_found', False)
 
         self.request = kwargs.get('request', {})
         self.response = kwargs.get('response', {})
@@ -118,9 +121,14 @@ class ProviderModel(object):
                 "retry": True,
             }
         except ResponseNotFoundException:
+            if self.retry_when_not_found:
+                return {
+                    "status": False,
+                    "retry": True,
+                }
             return {
                 "status": False,
-                "retry": True,
+                "retry": False,
             }
 
     def get_attr(self, key) -> str:
